=========
octopussh
=========

- 170 lines of Python 3 + Qt 5 App for modern Admins, single-file, No Dependencies, easy use.
- Inspired by Dead KSSH from KDE3 times ( http://kssh.sourceforge.net/#screenshots ).
- Generates Executable Bash scripts for Automated SSH so you dont need the App on other PCs.
- Tested OK on MS Windows 7 O.S. (you can not run SSH and Bash there but you can generate Scripts).


.. image:: https://raw.githubusercontent.com/juancarlospaco/octopussh/master/temp.jpg


Try it !:
=========

::

    wget -O - https://raw.githubusercontent.com/juancarlospaco/octopussh/master/octopussh | python3

Install permanently on the system:
==================================

::

    sudo apt-get install sshpass python3-pyqt5  # OR  sudo yum install python3-qt5 sshpass  OR  sudo pacman -S python-pyqt5 sshpass
    sudo pip3 install octopussh
    octopussh

Requisites:
===========

- `Python 3.x <https://www.python.org "Python Homepage">`_
- `PyQt 5.x <http://www.riverbankcomputing.co.uk/software/pyqt/download5>`_ : PyQt5 Homepage
- SSHPass (Linux package)


Donate, Charityware :
=====================

- `Charityware <https://en.wikipedia.org/wiki/Donationware>`_ is a licensing model that supplies fully operational unrestricted software to the user and requests an optional donation be paid to a third-party beneficiary non-profit. The amount of donation may be left to the discretion of the user. Its GPL-compatible and Enterprise ready.
- If you want to Donate please `click here <http://www.icrc.org/eng/donations/index.jsp>`_ or `click here <http://www.atheistalliance.org/support-aai/donate>`_ or `click here <http://www.msf.org/donate>`_ or `click here <http://richarddawkins.net/>`_ or `click here <http://www.supportunicef.org/>`_ or `click here <http://www.amnesty.org/en/donate>`_
